DECLARE FUNCTION MC03ExternalInput! (AdrModule AS INTEGER)
DECLARE SUB MC03Clear (AdrModule AS INTEGER)
DECLARE FUNCTION MC03ReadInput# (AdrModule AS INTEGER)
DECLARE FUNCTION MC03ReadInputLatched# (AdrModule AS INTEGER)
DECLARE FUNCTION MC03IsExternalInput (AdrModule AS INTEGER)

'  +-----------------------------------------------------------------------+
'   (C) SELIA design                                                  
'  +-----------------------------------------------------------------------
'   Tel :  (00 33) 88 86 68 54                                            
'   Fax :  (00 33) 88 86 74 76                                            
'  +-----------------------------------------------------------------------
'   Project     : CF01                 Compiler   : QBASIC               
'   Module name : MC03.BAS             Version    : 1.1                  
'  +-------------------------------+---------------------------------------
'   Author    : Francis GLOHR          Date       : 17 March 1994        
'  +-----------------------------------------------------------------------
'   Descript. :                                                           
'                Function to use the CF01 with MC03 modules               
'  +-----------------------------------------------------------------------
'                               UPDATES                                   
'  +-----------------------------------------------------------------------
'     Date      Author            Description of updates                
'  +----------+-----------+------------------------------------------------
'  17/03/94  F. Glohr    Creation V 1.00                                
'  --------- -----------------------------------------------------------
'  13/06/97  F. Glohr    Correction bug. Creation V 1.01                
'  --------- -----------------------------------------------------------
'  +-----------------------------------------------------------------------+

'  +-----------------------------------------------------------------------+
'   Const definition                                                      
'  +-----------------------------------------------------------------------+

' Base adress of the CF01 board is Hex 300 = Dec 768
' ****************************************************

CONST ESC = 27                                  ' ESC key definition
CONST TRUE = 1
CONST FLASE = NOT TRUE

'CONST AdrModule = AdrBase + 0                  ' Module at position A
'CONST AdrModule = AdrBase + 2                  ' Module at position B
'CONST AdrModule = AdrBase + 4                  ' Module at position C
CONST AdrModule = &H300 + 6                     ' Module at position D

' -------------------------------------------------------------------------
' Note: For over module position you must correct the constant ADRMODULE
'       with the correct module adresse as specified in the CF01 handbook
' -------------------------------------------------------------------------



'  +-----------------------------------------------------------------------+
'   Name :  main                                                          
'  +-----------------------------------------------------------------------
'   Description :                                                         
'     Example to use the MC03 module                                      
'  +-----------------------------------------------------------------------
'   Input :                                                               
'  +-----------------------------------------------------------------------
'   Output:                                                               
'  +-----------------------------------------------------------------------+

CLS                                             ' Clear current screen
LOCATE 10, 10: PRINT "Example for use the MC03 module with the CF01 board"
LOCATE 11, 10: PRINT STRING$(54, "-")

LOCATE 25, 10: PRINT "Press ESC key to quit program"

LOCATE 14, 5: PRINT "Counter                 :";
LOCATE 15, 5: PRINT "Counter (latched) value :";
LOCATE 16, 5: PRINT "External line status    :";

LOCATE 20, 10: PRINT "Press 'C' to clear the counter"


DO
   LOCATE 14, 31: PRINT USING "##########"; MC03ReadInput(AdrModule)
   LOCATE 15, 31: PRINT USING "##########"; MC03ReadInputLatched(AdrModule)

   IF MC03ExternalInput(AdrModule) = TRUE THEN
      s$ = "OK"
   ELSE
      s$ = "NOT OK"
   END IF
   LOCATE 16, 31: PRINT s$

   c$ = INKEY$
   IF c$ = "C" OR c$ = "c" THEN
      MC03Clear AdrModule
   END IF
LOOP UNTIL c$ = CHR$(ESC)

'  +-----------------------------------------------------------------------+
'   Name :  MC03Clear                                                     
'  +-----------------------------------------------------------------------
'   Description :                                                         
'     Clear 24 bit counter value                                          
'  +-----------------------------------------------------------------------
'   Input :  AdrModule AS INTEGER: Adress of the MC03 module (see Note)   
'  +-----------------------------------------------------------------------
'   Output:                                                               
'  +-----------------------------------------------------------------------+
SUB MC03Clear (AdrModule AS INTEGER)
   OUT AdrModule, 2                
   OUT AdrModule + 1, 0              
   OUT AdrModule, 1                  
   OUT AdrModule + 1, 0              
   OUT AdrModule, 0                  
   OUT AdrModule + 1, 0             
END SUB

'  +-----------------------------------------------------------------------+
'   Name :  MC03ExternalInput                                             
'  +-----------------------------------------------------------------------
'   Description :                                                         
'     Read the external line input                                        
'  +-----------------------------------------------------------------------
'   Input :  AdrModule AS INTEGER: Adress of the MC03 module (see Note)   
'  +-----------------------------------------------------------------------
'   Output:  TRUE is line ok else FALSE                                   
'  +-----------------------------------------------------------------------+
FUNCTION MC03ExternalInput (AdrModule AS INTEGER)
   status = INP(AdrModule)
   result = FALSE
   IF (status AND 1) = 0 THEN result = TRUE
   MC03ExternalLine = result
END FUNCTION

'  +-----------------------------------------------------------------------+
'   Name :  MC03ReadInput                                                 
'  +-----------------------------------------------------------------------
'   Description :                                                         
'     Read 24 bit counter value                                           
'  +-----------------------------------------------------------------------
'   Input :  AdrModule AS INTEGER: Adress of the MC03 module (see Note)   
'  +-----------------------------------------------------------------------
'   Output:  LONG : result from the reading of MC03                       
'  +-----------------------------------------------------------------------+
FUNCTION MC03ReadInput# (AdrModule AS INTEGER)
   OUT AdrModule, 0                ' Select LSB
   lsb  = INP(AdrModule + 1)          ' Read LSB (twice)
   lsb  = INP(AdrModule + 1)          ' Read LSB
   OUT AdrModule, 1                  ' Select MID
   mid  = INP(AdrModule + 1)          ' Read MID
   OUT AdrModule, 2                  ' Select MSB
   msb  = INP(AdrModule + 1)          ' Read MSB

   MC03ReadInput# = (msb * 256 * 256) + (mid * 256) + lsb
END FUNCTION

'  +-----------------------------------------------------------------------+
'   Name :  MC03ReadInputLatched                                          
'  +-----------------------------------------------------------------------
'   Description :                                                         
'     Read 24 bit external freezed counter value                          
'  +-----------------------------------------------------------------------
'   Input :  AdrModule AS INTEGER: Adress of the MC03 module (see Note)   
'  +-----------------------------------------------------------------------
'   Output:  LONG : result from the reading of MC03                       
'  +-----------------------------------------------------------------------+
FUNCTION MC03ReadInputLatched# (AdrModule AS INTEGER)
   OUT AdrModule, 4                ' Select LSB
   lsb = INP(AdrModule + 1)          ' Read LSB
   OUT AdrModule, 5                  ' Select MID
   mid = INP(AdrModule + 1)          ' Read MID
   OUT AdrModule, 6                  ' Select MSB
   msb = INP(AdrModule + 1)          ' Read MSB

   MC03ReadInputLatched# = (msb * 256 * 256) + (mid * 256) + lsb
END FUNCTION

